<?php

/**
 * @file
 * Contains Drupal\mespronos\Entity\Sport.
 */

namespace Drupal\mespronos\Entity;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\mespronos\Entity\Base\MPNContentEntityBase;
use Drupal\mespronos\Entity\Interfaces\MPNEntityInterface;

/**
 * Defines the Sport entity.
 *
 * @ingroup mespronos
 *
 * @ContentEntityType(
 *   id = "sport",
 *   label = @Translation("Sport"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\mespronos\Entity\Controller\SportListController",
 *     "views_data" = "Drupal\mespronos\Entity\ViewsData\SportViewsData",
 *
 *     "form" = {
 *       "default" = "Drupal\mespronos\Entity\Form\SportForm",
 *       "add" = "Drupal\mespronos\Entity\Form\SportForm",
 *       "edit" = "Drupal\mespronos\Entity\Form\SportForm",
 *       "delete" = "Drupal\mespronos\Entity\Form\MPNEntityDeleteForm",
 *     },
 *     "access" = "Drupal\mespronos\ControlHandler\SportAccessControlHandler",
 *   },
 *   base_table = "mespronos__sport",
 *   admin_permission = "administer Sport entity",
 *   fieldable = FALSE,
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "name",
 *     "uuid" = "uuid",
 *   },
 *   links = {
 *     "edit-form" = "/entity.sport.edit_form",
 *     "delete-form" = "/entity.sport.delete_form",
 *     "collection" = "/entity.sport.collection"
 *   }
 * )
 */
class Sport extends MPNContentEntityBase implements MPNEntityInterface {
  /**
   * {@inheritdoc}
   */
  public static function preCreate(EntityStorageInterface $storage_controller, array &$values) {
    parent::preCreate($storage_controller, $values);
    $values += array(
      'creator' => \Drupal::currentUser()->id(),
    );
  }

  /**
   * @param array $values
   * @return Sport
   * @throws \Exception
   */
  public static function create(array $values = array()) {
    if (!isset($values['name']) || empty(trim($values['name']))) {
      throw new \Exception(t('Sport name should not be empty'));
    }
    $query = \Drupal::entityQuery('sport')->condition('name', '%'.$values['name'].'%', 'LIKE');
    $id = $query->execute();
    if (count($id) == 0) {
      return parent::create($values); // TODO: Change the autogenerated stub
    } else {
      $sport = entity_load('sport', array_pop($id));
      return $sport;
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['creator'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Authored by'))
      ->setDescription(t('The user ID of the Sport entity author.'))
      ->setRevisionable(TRUE)
      ->setSetting('target_type', 'user')
      ->setSetting('handler', 'default')
      ->setRequired(TRUE)
      ->setDefaultValueCallback('Drupal\node\Entity\Node::getCurrentUserId')
      ->setDisplayOptions('view', array(
        'label' => 'hidden',
        'type' => 'author',
        'weight' => 0,
      ))
      ->setDisplayOptions('form', array(
        'type' => 'entity_reference_autocomplete',
        'weight' => 5,
        'settings' => array(
          'match_operator' => 'CONTAINS',
          'size' => '60',
          'autocomplete_type' => 'tags',
          'placeholder' => '',
        ),
      ))
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['name'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Name'))
      ->setDescription(t('The name of the Sport entity.'))
      ->setTranslatable(true)
      ->setRequired(TRUE)
      ->setSettings(array(
        'default_value' => '',
        'max_length' => 50,
        'text_processing' => 0,
      ))
      ->setDisplayOptions('view', array(
        'label' => 'above',
        'type' => 'string',
        'weight' => -4,
      ))
      ->setDisplayOptions('form', array(
        'type' => 'string_textfield',
        'weight' => -4,
      ))
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    return $fields;
  }

}
